@@ -251,7 +251,7 @@ void GridWorld::add_agents(GroupHandle group, int n, const char *method,
                 }
 
                 agent->set_dir(turn_mode ? (Direction) pos_dir[i] : NORTH);
-                agent->set_pos((Position) {pos_x[i], pos_y[i]});
+                agent->set_pos({pos_x[i], pos_y[i]});
 
                 ret = map.add_agent(agent, base_channel_id);
                 add_or_error(ret, pos_x[i], pos_y[i], id_counter, g, agent);
@@ -463,7 +463,7 @@ void GridWorld::step(int *done) {
 
     // shuffle attacks
     for (int i = 0; i < attack_size; i++) {
-        int j = (int)random_engine() % (i+1);
+        int j = (int)random_engine() % (unsigned long)(i+1);
         std::swap(attack_buffer[i], attack_buffer[j]);
     }
 
