@@ -49,8 +49,8 @@ void Map::reset(int width, int height, bool food_mode) {
 Position Map::get_random_blank(std::default_random_engine &random_engine, int width, int height) {
     int tries = 0;
     while (true) {
-        int x = (int) random_engine() % (w - width);
-        int y = (int) random_engine() % (h - height);
+        int x = (int) random_engine() % (unsigned long)(w - width);
+        int y = (int) random_engine() % (unsigned long)(h - height);
 
         if (is_blank_area(x, y, width, height)) {
             return Position{x, y};
@@ -420,7 +420,7 @@ int Map::get_align(Agent *agent) {
         ((Agent *)slots[pos_int].occupier)->get_group() == group);
 
     pos_int = pos2int(pos);
-    do {  // negtive direction
+    do {  // negative direction
         x_align++;
         pos_int--;
     } while (slots[pos_int].occupier != nullptr &&
@@ -436,7 +436,7 @@ int Map::get_align(Agent *agent) {
         ((Agent *)slots[pos_int].occupier)->get_group() == group);
 
     pos_int = pos2int(pos);
-    do {  // negtive direction
+    do {  // negative direction
         y_align++;
         pos_int -= MAP_INNER_Y_ADD;
     } while (slots[pos_int].occupier != nullptr &&
